@@ -160,8 +160,11 @@ class AutoTrader():
         # Scan Parameters
         self.scan_mode = False
         self.scan_index = None
+        self.scan_watchlist = None
         self.scan_results = {}
         
+        # Plotting
+        self._custom_ap_settings = False
         
     def run(self):
         '''
@@ -178,6 +181,10 @@ class AutoTrader():
         for strat_config_file in self._uninitiated_strat_files:
             self.add_strategy(strategy_filename=strat_config_file)
         
+        if self.scan_watchlist is not None:
+            # Scan watchlist has not overwritten strategy watchlist
+            self._update_strategy_watchlist()
+        
         # Print help
         if self.show_help is not None:
             printout.option_help(self.show_help)
@@ -265,8 +272,8 @@ class AutoTrader():
                 print("  To:   ", datetime.strftime(self.data_end,'%d/%m/%Y %H:%M'))
                 # print("  Instruments: ", self.watchlist)
             elif self.scan_mode:
-                print("AutoScan:")
-                print("Time: {}".format(datetime.now().strftime("%A, %B %d %Y, "+
+                print("AutoTrader - AutoScan")
+                print("Time: {}\n".format(datetime.now().strftime("%A, %B %d %Y, "+
                                                                   "%H:%M:%S")))
             else:
                 print("AutoTrader Livetrade")
@@ -363,6 +370,13 @@ class AutoTrader():
                     ap._plot_multibot_backtest(self.multibot_backtest_results, 
                                               NAV,
                                               cpl_dict)
+        
+        elif self.scan_mode and self.show_plot:
+            # Show plots for scanned instruments
+            for bot in self.bots_deployed:
+                ap = self._instantiate_autoplot(bot.data)
+                ap.plot(indicators = bot.strategy.indicators, 
+                        instrument = bot.instrument)
 
     def _clear_strategies(self):
         '''
@@ -377,7 +391,42 @@ class AutoTrader():
         '''
         
         self.bots_deployed = []
+    
+    def plot_settings(self, max_indis_over=3, max_indis_below=2,
+                      fig_tools="pan,wheel_zoom,box_zoom,undo,redo,reset,save,crosshair",
+                      ohlc_height=400, ohlc_width=800, top_fig_height=150,
+                      bottom_fig_height=150):
+        ''' Configures settings for AutoPlot. '''
         
+        # Set flag for custom settings
+        self._custom_ap_settings = True
+        
+        # Assign attributes
+        self.max_indis_over     = max_indis_over
+        self.max_indis_below    = max_indis_below
+        self.fig_tools          = fig_tools
+        self.ohlc_height        = ohlc_height
+        self.ohlc_width         = ohlc_width
+        self.top_fig_height     = top_fig_height
+        self.bottom_fig_height  = bottom_fig_height
+    
+    def _instantiate_autoplot(self, data):
+        ''' Creates instance of AutoPlot. '''
+        
+        # Create nominal instance
+        ap = autoplot.AutoPlot(data)
+        
+        if self._custom_ap_settings:
+            # Assign attributes
+            ap.max_indis_over     = self.max_indis_over
+            ap.max_indis_below    = self.max_indis_below
+            ap.fig_tools          = self.fig_tools
+            ap.ohlc_height        = self.ohlc_height
+            ap.ohlc_width         = self.ohlc_width
+            ap.top_fig_height     = self.top_fig_height
+            ap.bottom_fig_height  = self.bottom_fig_height
+        
+        return ap
     
     def add_strategy(self, strategy_filename=None, 
                      strategy_dict=None):
@@ -521,27 +570,39 @@ class AutoTrader():
         self.MTF_initialisation = MTF_initialisation
         
     
-    def scan(self, scan_index=None):
+    def scan(self, strategy_filename=None, scan_index=None):
         '''
         Configure AutoTrader scan. 
             
             Parameters:
+                strategy_filename (str): prefix of yaml strategy
+                configuration file, located in home_dir/config.
+                    
                 scan_index (str): index to scan.
         '''
         
+        # If a strategy is provided here, add it
+        if strategy_filename is not None:
+            self.add_strategy(strategy_filename)
+        
         # If scan index provided, use that. Else, use strategy watchlist
         if scan_index is not None:
-            scan_watchlist = instrument_list.get_watchlist(scan_index)
-            
-            # Update strategy watchlist
-            for strategy in self.strategies:
-                self.strategies[strategy]['WATCHLIST'] = scan_watchlist
+            self.scan_watchlist = instrument_list.get_watchlist(scan_index,
+                                                                self.feed)
+
         else:
             scan_index = 'Strategy watchlist'
             
-        
         self.scan_mode = True
         self.scan_index = scan_index
+        self.check_data_alignment = False
+    
+    
+    def _update_strategy_watchlist(self):
+        ''' Updates the watchlist of each strategy with the scan watchlist. '''
+        
+        for strategy in self.strategies:
+            self.strategies[strategy]['WATCHLIST'] = self.scan_watchlist
     
     
     def plot_backtest(self, bot=None):
@@ -769,9 +830,15 @@ class AutoTrader():
                 
                 
         else:
-            utils_module    = importlib.import_module('autotrader.brokers.{}.utils'.format(self.feed.lower()))
-            utils           = utils_module.Utils()
-            broker          = Oanda.Oanda(broker_config, utils)
+            
+            if self.feed.lower() == 'yahoo':
+                utils_module    = importlib.import_module('autotrader.brokers.virtual.utils')
+                utils           = utils_module.Utils()
+                broker          = Broker(broker_config, utils)
+            else:
+                utils_module    = importlib.import_module('autotrader.brokers.{}.utils'.format(self.feed.lower()))
+                utils           = utils_module.Utils()
+                broker          = Oanda.Oanda(broker_config, utils) # TODO - generalise away from Oanda
         
         self.broker = broker
         self.broker_utils = utils
